@@ -1,5 +1,5 @@
 package GitHub::MergeVelocity::Repository;
-$GitHub::MergeVelocity::Repository::VERSION = '0.000007';
+our $VERSION = '0.000008';
 use strict;
 use warnings;
 
@@ -82,6 +82,8 @@ sub _get_pull_requests {
         params => { per_page => 100, state => 'all' },
     );
 
+    $result->auto_pagination(1);
+
     my @pulls;
 
     while ( my $row = $result->next ) {
@@ -130,7 +132,7 @@ GitHub::MergeVelocity::Repository - Encapsulate pull request data for a reposito
 
 =head1 VERSION
 
-version 0.000007
+version 0.000008
 
 =head1 AUTHOR
 
